@@ -83,7 +83,7 @@ static const int _upcparenc[10][2][6] = {
 //! @todo New Renderer Functions
 ////////////////////////////////////////////////////////
 
-void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int align)
+void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, Qt::Alignment align)
 {
     int val[13];
 
@@ -151,13 +151,14 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) { // center
+    if (align == Qt::AlignHCenter) {
         qreal nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone)
             quiet_zone = nqz;
-    } else if (align > 1) // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     qreal pos = r.left() + quiet_zone;
     qreal top = r.top();
@@ -171,7 +172,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -179,7 +180,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += bar_width;
 
@@ -192,7 +193,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - 0.07));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -205,7 +206,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -213,7 +214,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -226,7 +227,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - 0.07));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -237,7 +238,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -245,7 +246,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     QString parstr = QString::fromLatin1("%1").arg(val[0]);
     QString leftstr = QString().sprintf("%d%d%d%d%d%d",
@@ -260,7 +261,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setFont(font);
     tb->setText(parstr);
     tb->setFlags(Qt::AlignRight | Qt::AlignTop);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 0.03, (r.top() + draw_height) - 0.07));
@@ -268,7 +269,7 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setFont(font);
     tb->setText(leftstr);
     tb->setFlags(Qt::AlignHCenter | Qt::AlignTop);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 0.5, (r.top() + draw_height) - 0.07));
@@ -276,10 +277,10 @@ void renderCodeEAN13(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setFont(font);
     tb->setText(rightstr);
     tb->setFlags(Qt::AlignHCenter | Qt::AlignTop);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 }
 
-void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int align)
+void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, Qt::Alignment align)
 {
     int val[13];
 
@@ -347,13 +348,14 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) { // center
+    if (align == Qt::AlignHCenter) {
         qreal nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone)
             quiet_zone = nqz;
-    } else if (align > 1) // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     qreal pos = r.left() + quiet_zone;
     qreal top = r.top();
@@ -366,7 +368,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -374,7 +376,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += bar_width;
 
@@ -387,7 +389,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - (i == 0 ? 0 : 0.07)));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -399,7 +401,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -407,7 +409,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -420,7 +422,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - (i == 5 ? 0 : 0.07)));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -431,7 +433,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -439,7 +441,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     QString parstr = QString::number(val[1]);
     QString chkstr = QString::number(val[12]);
@@ -449,7 +451,7 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
                                          val[7], val[8], val[9], val[10], val[11]);
 
     QFont font(QLatin1String("Arial"), 6);
-    KRTextStyleData ts;
+    KReportTextStyleData ts;
     ts.backgroundColor = Qt::white;
     ts.font = font;
     ts.foregroundColor = Qt::black;
@@ -462,31 +464,31 @@ void renderCodeUPCA(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setTextStyle(ts);
     tb->setText(parstr);
 
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 10, (r.top() + draw_height) - 7));
     tb->setSize(QSizeF(35, 10));
     tb->setTextStyle(ts);
     tb->setText(leftstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 50, (r.top() + draw_height) - 7));
     tb->setSize(QSizeF(35, 10));
     tb->setTextStyle(ts);
     tb->setText(rightstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + L + 2, (r.top() + draw_height) - 12));
     tb->setSize(QSizeF(8, 12));
     tb->setTextStyle(ts);
     tb->setText(chkstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 }
 
-void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int align)
+void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, Qt::Alignment align)
 {
     int val[8];
 
@@ -555,13 +557,14 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) { // center
+    if (align ==  Qt::AlignHCenter) {
         qreal nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone)
             quiet_zone = nqz;
-    } else if (align > 1) // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     qreal pos = r.left() + quiet_zone;
     qreal top = r.top();
@@ -574,7 +577,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -582,7 +585,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += bar_width;
 
@@ -595,7 +598,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - 0.06));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -608,7 +611,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -616,7 +619,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -629,7 +632,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - 0.06));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -640,7 +643,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -648,7 +651,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     QString leftstr = QString().sprintf("%d%d%d%d",
                                         val[0], val[1], val[2], val[3]);
@@ -662,7 +665,7 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setFont(font);
     tb->setText(leftstr);
     tb->setFlags(Qt::AlignHCenter | Qt::AlignTop);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 0.36, (r.top() + draw_height) - 0.06));
@@ -670,10 +673,10 @@ void renderCodeEAN8(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setFont(font);
     tb->setText(rightstr);
     tb->setFlags(Qt::AlignHCenter | Qt::AlignTop);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 }
 
-void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int align)
+void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, Qt::Alignment align)
 {
     int val[8];
 
@@ -734,13 +737,14 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     //
     // calculate the starting position based on the alignment option
     // for left align we don't need to do anything as the values are already setup for it
-    if (align == 1) { // center
+    if (align == Qt::AlignHCenter) {
         qreal nqz = (draw_width - L) / 2;
         if (nqz > quiet_zone)
             quiet_zone = nqz;
-    } else if (align > 1) // right
+    } else if (align == Qt::AlignRight) {
         quiet_zone = draw_width - (L + quiet_zone);
-    // else if(align < 1) {} // left : do nothing
+    }
+    // left : do nothing
 
     qreal pos = r.left() + quiet_zone;
     qreal top = r.top();
@@ -753,7 +757,7 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -761,7 +765,7 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += bar_width;
 
@@ -774,7 +778,7 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
                 rect->setPen(pen);
                 rect->setBrush(brush);
                 rect->setRect(QRectF(pos, top, bar_width, draw_height - 7));
-                page->addPrimitive(rect);
+                page->insertPrimitive(rect);
             }
             pos += bar_width;
         }
@@ -787,7 +791,7 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -795,7 +799,7 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     pos += (bar_width * 2.0);
 
@@ -805,14 +809,14 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     rect->setPen(pen);
     rect->setBrush(brush);
     rect->setRect(QRectF(pos, top, bar_width, draw_height));
-    page->addPrimitive(rect);
+    page->insertPrimitive(rect);
 
     QString parstr = QString::number(val[0]);
     QString chkstr = QString::number(val[7]);
     QString leftstr = QString().sprintf("%d%d%d%d%d%d",
                                         val[1], val[2], val[3], val[4], val[5], val[6]);
     QFont font(QLatin1String("Arial"), 6);
-    KRTextStyleData ts;
+    KReportTextStyleData ts;
     ts.backgroundColor = Qt::white;
     ts.font = font;
     ts.foregroundColor = Qt::black;
@@ -824,19 +828,19 @@ void renderCodeUPCE(OROPage * page, const QRectF & r, const QString & _str, int
     tb->setSize(QSizeF(quiet_zone - 2, 12));
     tb->setTextStyle(ts);
     tb->setText(parstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + 3, (r.top() + draw_height) - 7));
     tb->setSize(QSizeF(42, 10));
     tb->setTextStyle(ts);
     tb->setText(leftstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 
     tb = new OROTextBox();
     tb->setPosition(QPointF(r.left() + quiet_zone + L + 2, r.top() + draw_height - 12));
     tb->setSize(QSizeF(8, 12));
     tb->setTextStyle(ts);
     tb->setText(chkstr);
-    page->addPrimitive(tb);
+    page->insertPrimitive(tb);
 }
